#' @export
#' @import stats
rlse_beta <- function(p, alpha, beta) {
    SE <- function(p, alpha, beta) {
        fn = function(x) {
            (stats::dbeta(x,alpha, beta)) * ((stats::dbeta(x,alpha, beta, log = TRUE)) - log(stats::pbeta(p[i],
                alpha, beta)))
        }
        ES = p
        for (i in 1:length(p)) {
            ES[i] = (stats::integrate(fn, lower = 0, upper = p[i], stop.on.error = FALSE)$value)
        }
        return(ES)
    }
    sinc <- -1 * (1/stats::pbeta(p, alpha, beta)) * SE(p, alpha, beta)
    ((Se_beta(alpha, beta) - sinc))/(Se_beta(alpha, beta))
}

#' @export
rlre_beta <- function(p, alpha, beta, delta) {
    RE <- function(p, alpha, beta, delta) {
        fn = function(x) {
            (stats::dbeta(x, alpha, beta))^delta
        }
        ES = p
        for (i in 1:length(p)) {
            ES[i] = (stats::integrate(fn, lower = 0, upper = p[i], stop.on.error = FALSE)$value)
        }
        return(ES)
    }

    rinc <- (1/(1 - delta)) * log((1/stats::pbeta(p, alpha, beta))^delta * RE(p,
        alpha, beta, delta))

    (re_beta(alpha, beta, delta) - rinc)/re_beta(alpha, beta, delta)
}

#' @export
rlhce_beta <- function(p, alpha, beta, delta) {
    HC <- function(p, alpha, beta, delta) {
        fn = function(x) {
            (stats::dbeta(x, alpha, beta))^delta
        }
        ES = p
        for (i in 1:length(p)) {
            ES[i] = (stats::integrate(fn, lower = 0, upper = p[i], stop.on.error = FALSE)$value)
        }
        return(ES)
    }
    hcinc <- (1/(2^(1 - delta) - 1)) * (((1/stats::pbeta(p, alpha, beta))^delta *
        HC(p, alpha, beta, delta)) - 1)
    (hce_beta(alpha, beta, delta) - hcinc)/hce_beta(alpha, beta, delta)
}

#' @export
rlae_beta <- function(p, alpha, beta, delta) {
    AE <- function(p, alpha, beta, delta) {
        fn = function(x) {
            (stats::dbeta(x, alpha, beta))^delta
        }
        ES = p
        for (i in 1:length(p)) {
            ES[i] = (stats::integrate(fn, lower = 0, upper = p[i], stop.on.error = FALSE)$value)
        }
        return(ES)
    }
    ainc <- (delta/(1 - delta)) * (((1/stats::pbeta(p, alpha, beta))^delta * AE(p,
        alpha, beta, delta))^(1/delta) - 1)

    (ae_beta(alpha, beta, delta) - ainc)/ae_beta(alpha, beta, delta)
}
